# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, Optional
from zitadel_client.models.user_service_auth_factor_state import UserServiceAuthFactorState
from zitadel_client.models.user_service_auth_factor_u2_f import UserServiceAuthFactorU2F
from typing import Optional, Set
from typing_extensions import Self

class UserServiceAuthFactor(BaseModel):
    """
    UserServiceAuthFactor
    """ # noqa: E501
    state: Optional[UserServiceAuthFactorState] = None
    otp: Optional[Dict[str, Any]] = None
    otp_email: Optional[Dict[str, Any]] = Field(default=None, alias="otpEmail")
    otp_sms: Optional[Dict[str, Any]] = Field(default=None, alias="otpSms")
    u2f: Optional[UserServiceAuthFactorU2F] = None
    __properties: ClassVar[List[str]] = ["state", "otp", "otpEmail", "otpSms", "u2f"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UserServiceAuthFactor from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of u2f
        if self.u2f:
            _dict['u2f'] = self.u2f.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UserServiceAuthFactor from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "state": obj.get("state"),
            "otp": obj.get("otp"),
            "otpEmail": obj.get("otpEmail"),
            "otpSms": obj.get("otpSms"),
            "u2f": UserServiceAuthFactorU2F.from_dict(obj["u2f"]) if obj.get("u2f") is not None else None
        })
        return _obj


